/*------------------------------------------------------------------------------
--  This file is a part of the VHDL Tools Software
--  Copyright (C) 2014, Plasma Physics Laboratory - CNRS
--
--  This program is free software; you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation; either version 2 of the License, or
--  (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
--  You should have received a copy of the GNU General Public License
--  along with this program; if not, write to the Free Software
--  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-------------------------------------------------------------------------------*/
/*--                  Author : Alexis Jeandet
--                     Mail : alexis.jeandet@member.fsf.org
----------------------------------------------------------------------------*/
#include "vhdl_ast_node.h"



VHDL_Tools::VHDL_AST_Node::VHDL_AST_Node(const QString &value, VHDL_Tools::VHDL_AST_Node_type type, int line, int column)
    :a_value(value),type(type),line(line),column(column),p_parent(NULL)
{

}

VHDL_Tools::VHDL_AST_Node::~VHDL_AST_Node()
{
    for(int i=0;i<childs.count();i++)
    {
        VHDL_AST_Node* nd=childs.first();
        childs.removeFirst();
        delete nd;
    }
}

void VHDL_Tools::VHDL_AST_Node::move(VHDL_Tools::VHDL_AST_Node *parentNode)
{
    if(parentNode!=NULL)
    {
        if(this->p_parent)
        {
            this->p_parent->childs.removeOne(this);
        }
        parentNode->childs.append(this);
        this->p_parent=parentNode;
    }
}

void VHDL_Tools::VHDL_AST_Node::moveWithoutChilds(VHDL_Tools::VHDL_AST_Node *parentNode)
{
    if(parentNode!=NULL)
    {
        if(this->p_parent)
        {
            this->p_parent->childs.removeOne(this);
        }
        while(Q_UNLIKELY(this->childs.isEmpty()))
        {
            VHDL_Tools::VHDL_AST_Node *child = this->childs.first();
            this->childs.removeAll(child);
            this->p_parent->childs.append(child);
        }
        parentNode->childs.append(this);
        this->p_parent=parentNode;
    }
}
